@@ -3,7 +3,9 @@
 // Use is subject to license terms.
 //
 
-use serde::{Deserialize, Serialize};
+// derive(juniper::GraphQLEnum) triggers this lint
+#![allow(clippy::use_self)]
+
 use serde_with::{DeserializeFromStr, SerializeDisplay};
 
 use super::*;
@@ -13,6 +15,7 @@ mod impls;
 #[derive(
     Clone, Copy, Debug, PartialEq, Eq, PartialOrd, Ord, Hash, SerializeDisplay, DeserializeFromStr,
 )]
+#[cfg_attr(feature = "graphql", derive(juniper::GraphQLEnum))]
 #[cfg_attr(feature = "jsonschema", derive(schemars::JsonSchema))]
 pub enum AzureRegion {
     CentralUs,
@@ -26,8 +29,3 @@ pub enum AzureRegion {
     WestEurope,
     WestUs2,
 }
-
-#[derive(Clone, Debug, PartialEq, Eq, Hash, Serialize, Deserialize)]
-pub struct PrivateLinkServiceAzure {
-    pub id: String,
-}
