@@ -18,7 +18,7 @@ pub trait CloudLocation {
     fn as_str(&self) -> &'static str;
 }
 
-#[derive(Clone, Copy, Debug, Eq, Hash, PartialEq, Serialize, Deserialize)]
+#[derive(Clone, Copy, Debug, PartialEq, Eq, PartialOrd, Ord, Hash, Serialize, Deserialize)]
 #[cfg_attr(feature = "jsonschema", derive(schemars::JsonSchema))]
 pub enum Location {
     Aws(aws::AwsRegion),
